@@ -53,6 +53,9 @@ __all__ = [
     "AUDIO_FORMATS"
 ]
 
+
+# Constants, enums, and macros
+
 SDL_AudioFormat = Uint16
 
 SDL_AUDIO_MASK_BITSIZE = 0xFF
@@ -82,7 +85,6 @@ AUDIO_F32LSB = 0x8120
 AUDIO_F32MSB = 0x9120
 AUDIO_F32 = AUDIO_F32LSB
 
-
 # All of the audio formats should be in this set which is provided as a
 # convenience to the end user for purposes of iteration and validation.
 # (is the provided audio format in the supported set?)
@@ -98,10 +100,13 @@ FORMAT_NAME_MAP = {
     AUDIO_F32LSB: "AUDIO_F32LSB",
     AUDIO_F32MSB: "AUDIO_F32MSB",
 }
-AUDIO_FORMATS = set([AUDIO_U8, AUDIO_S8, AUDIO_U16LSB, AUDIO_S16LSB,
-                     AUDIO_U16MSB, AUDIO_S16MSB, AUDIO_U16, AUDIO_S16,
-                     AUDIO_S32LSB, AUDIO_S32MSB, AUDIO_S32, AUDIO_F32LSB,
-                     AUDIO_F32MSB, AUDIO_F32])
+AUDIO_FORMATS = set([
+    AUDIO_U8, AUDIO_S8,
+    AUDIO_U16LSB, AUDIO_U16MSB, AUDIO_U16,
+    AUDIO_S16LSB, AUDIO_S16MSB, AUDIO_S16,
+    AUDIO_S32LSB, AUDIO_S32MSB, AUDIO_S32,
+    AUDIO_F32LSB, AUDIO_F32MSB, AUDIO_F32
+])
 
 if SDL_BYTEORDER == SDL_LIL_ENDIAN:
     AUDIO_U16SYS = AUDIO_U16LSB
@@ -123,21 +128,37 @@ SDL_AUDIO_ALLOW_ANY_CHANGE = (
     SDL_AUDIO_ALLOW_CHANNELS_CHANGE | SDL_AUDIO_ALLOW_SAMPLES_CHANGE
 )
 
+SDL_AudioDeviceID = Uint32
+
+SDL_AudioStatus = c_int
+SDL_AUDIO_STOPPED = 0
+SDL_AUDIO_PLAYING = 1
+SDL_AUDIO_PAUSED = 2
+
+SDL_MIX_MAXVOLUME = 128
+SDL_AUDIOCVT_MAX_FILTERS = 9
+
+
+# Structure, opaque type, and callback definitions
+
 SDL_AudioCallback = CFUNCTYPE(None, c_void_p, POINTER(Uint8), c_int)
 
 class SDL_AudioSpec(Structure):
-    _fields_ = [("freq", c_int),
-                ("format", SDL_AudioFormat),
-                ("channels", Uint8),
-                ("silence", Uint8),
-                ("samples", Uint16),
-                ("padding", Uint16),
-                ("size", Uint32),
-                ("callback", SDL_AudioCallback),
-                ("userdata", c_void_p)
-                ]
-    def __init__(self, freq, aformat, channels, samples,
-                 callback=SDL_AudioCallback(), userdata=c_void_p(0)):
+    _fields_ = [
+        ("freq", c_int),
+        ("format", SDL_AudioFormat),
+        ("channels", Uint8),
+        ("silence", Uint8),
+        ("samples", Uint16),
+        ("padding", Uint16),
+        ("size", Uint32),
+        ("callback", SDL_AudioCallback),
+        ("userdata", c_void_p),
+    ]
+    def __init__(
+        self, freq, aformat, channels, samples, callback=SDL_AudioCallback(),
+        userdata=c_void_p(0)
+    ):
         super(SDL_AudioSpec, self).__init__()
         self.freq = freq
         self.format = aformat
@@ -146,43 +167,41 @@ class SDL_AudioSpec(Structure):
         self.callback = callback
         self.userdata = userdata
 
-SDL_AUDIOCVT_MAX_FILTERS = 9
-
 class SDL_AudioCVT(Structure):
     pass
 
 SDL_AudioFilter = CFUNCTYPE(POINTER(SDL_AudioCVT), SDL_AudioFormat)
-SDL_AudioCVT._fields_ = [("needed", c_int),
-                         ("src_format", SDL_AudioFormat),
-                         ("dst_format", SDL_AudioFormat),
-                         ("rate_incr", c_double),
-                         ("buf", POINTER(Uint8)),
-                         ("len", c_int),
-                         ("len_cvt", c_int),
-                         ("len_mult", c_int),
-                         ("len_ratio", c_double),
-                         ("filters", (SDL_AudioFilter * (SDL_AUDIOCVT_MAX_FILTERS+1))),
-                         ("filter_index", c_int)
-                        ]
+
+SDL_AudioCVT._fields_ = [
+    ("needed", c_int),
+    ("src_format", SDL_AudioFormat),
+    ("dst_format", SDL_AudioFormat),
+    ("rate_incr", c_double),
+    ("buf", POINTER(Uint8)),
+    ("len", c_int),
+    ("len_cvt", c_int),
+    ("len_mult", c_int),
+    ("len_ratio", c_double),
+    ("filters", (SDL_AudioFilter * (SDL_AUDIOCVT_MAX_FILTERS+1))),
+    ("filter_index", c_int),
+]
 
 class SDL_AudioStream(c_void_p):
     pass
 
+
+# Raw ctypes function definitions
+
 SDL_GetNumAudioDrivers = _bind("SDL_GetNumAudioDrivers", None, c_int)
 SDL_GetAudioDriver = _bind("SDL_GetAudioDriver", [c_int], c_char_p)
 SDL_AudioInit = _bind("SDL_AudioInit", [c_char_p], c_int)
 SDL_AudioQuit = _bind("SDL_AudioQuit")
 SDL_GetCurrentAudioDriver = _bind("SDL_GetCurrentAudioDriver", None, c_char_p)
 SDL_OpenAudio = _bind("SDL_OpenAudio", [POINTER(SDL_AudioSpec), POINTER(SDL_AudioSpec)], c_int)
-SDL_AudioDeviceID = Uint32
 SDL_GetNumAudioDevices = _bind("SDL_GetNumAudioDevices", [c_int], c_int)
 SDL_GetAudioDeviceName = _bind("SDL_GetAudioDeviceName", [c_int, c_int], c_char_p)
 SDL_GetAudioDeviceSpec = _bind("SDL_GetAudioDeviceSpec", [c_int, c_int, POINTER(SDL_AudioSpec)], c_int, added='2.0.16')
 SDL_OpenAudioDevice = _bind("SDL_OpenAudioDevice", [c_char_p, c_int, POINTER(SDL_AudioSpec), POINTER(SDL_AudioSpec), c_int], SDL_AudioDeviceID)
-SDL_AUDIO_STOPPED = 0
-SDL_AUDIO_PLAYING = 1
-SDL_AUDIO_PAUSED = 2
-SDL_AudioStatus = c_int
 SDL_GetAudioStatus = _bind("SDL_GetAudioStatus", None, SDL_AudioStatus)
 SDL_GetAudioDeviceStatus = _bind("SDL_GetAudioDeviceStatus", [SDL_AudioDeviceID], SDL_AudioStatus)
 SDL_PauseAudio = _bind("SDL_PauseAudio", [c_int])
@@ -192,7 +211,6 @@ SDL_LoadWAV = lambda f, s, ab, al: SDL_LoadWAV_RW(SDL_RWFromFile(f, b"rb"), 1, s
 SDL_FreeWAV = _bind("SDL_FreeWAV", [POINTER(Uint8)])
 SDL_BuildAudioCVT = _bind("SDL_BuildAudioCVT", [POINTER(SDL_AudioCVT), SDL_AudioFormat, Uint8, c_int, SDL_AudioFormat, Uint8, c_int], c_int)
 SDL_ConvertAudio = _bind("SDL_ConvertAudio", [POINTER(SDL_AudioCVT)], c_int)
-SDL_MIX_MAXVOLUME = 128
 SDL_MixAudio = _bind("SDL_MixAudio", [POINTER(Uint8), POINTER(Uint8), Uint32, c_int])
 SDL_MixAudioFormat = _bind("SDL_MixAudioFormat", [POINTER(Uint8), POINTER(Uint8), SDL_AudioFormat, Uint32, c_int])
 SDL_LockAudio = _bind("SDL_LockAudio")
