@@ -244,53 +244,53 @@ SDL_PIXELFORMAT_NV12 = SDL_DEFINE_PIXELFOURCC('N', 'V', '1', '2')
 SDL_PIXELFORMAT_NV21 = SDL_DEFINE_PIXELFOURCC('N', 'V', '2', '1')
 SDL_PIXELFORMAT_EXTERNAL_OES = SDL_DEFINE_PIXELFOURCC('O', 'E', 'S', ' ')
 
-ALL_PIXELFORMATS = [
-    SDL_PIXELFORMAT_INDEX1LSB,
-    SDL_PIXELFORMAT_INDEX1MSB,
-    SDL_PIXELFORMAT_INDEX4LSB,
-    SDL_PIXELFORMAT_INDEX4MSB,
-    SDL_PIXELFORMAT_INDEX8,
-    SDL_PIXELFORMAT_RGB332,
-    SDL_PIXELFORMAT_RGB444,
-    SDL_PIXELFORMAT_RGB555,
-    SDL_PIXELFORMAT_BGR555,
-    SDL_PIXELFORMAT_ARGB4444,
-    SDL_PIXELFORMAT_RGBA4444,
-    SDL_PIXELFORMAT_ABGR4444,
-    SDL_PIXELFORMAT_BGRA4444,
-    SDL_PIXELFORMAT_ARGB1555,
-    SDL_PIXELFORMAT_RGBA5551,
-    SDL_PIXELFORMAT_ABGR1555,
-    SDL_PIXELFORMAT_BGRA5551,
-    SDL_PIXELFORMAT_RGB565,
-    SDL_PIXELFORMAT_BGR565,
-    SDL_PIXELFORMAT_RGB24,
-    SDL_PIXELFORMAT_BGR24,
-    SDL_PIXELFORMAT_RGB888,
-    SDL_PIXELFORMAT_RGBX8888,
-    SDL_PIXELFORMAT_BGR888,
-    SDL_PIXELFORMAT_BGRX8888,
-    SDL_PIXELFORMAT_ARGB8888,
-    SDL_PIXELFORMAT_RGBA8888,
-    SDL_PIXELFORMAT_ABGR8888,
-    SDL_PIXELFORMAT_BGRA8888,
-    SDL_PIXELFORMAT_ARGB2101010,
-    SDL_PIXELFORMAT_RGBA32,
-    SDL_PIXELFORMAT_ARGB32,
-    SDL_PIXELFORMAT_BGRA32,
-    SDL_PIXELFORMAT_ABGR32,
-    SDL_PIXELFORMAT_YV12,
-    SDL_PIXELFORMAT_IYUV,
-    SDL_PIXELFORMAT_YUY2,
-    SDL_PIXELFORMAT_UYVY,
-    SDL_PIXELFORMAT_YVYU,
-    SDL_PIXELFORMAT_NV12,
-    SDL_PIXELFORMAT_NV21,
-    SDL_PIXELFORMAT_EXTERNAL_OES
-]
+NAME_MAP = {
+    'INDEX1LSB': SDL_PIXELFORMAT_INDEX1LSB,
+    'INDEX1MSB': SDL_PIXELFORMAT_INDEX1MSB,
+    'INDEX4LSB': SDL_PIXELFORMAT_INDEX4LSB,
+    'INDEX4MSB': SDL_PIXELFORMAT_INDEX4MSB,
+    'INDEX8': SDL_PIXELFORMAT_INDEX8,
+    'RGB332': SDL_PIXELFORMAT_RGB332,
+    'RGB444': SDL_PIXELFORMAT_RGB444,
+    'RGB555': SDL_PIXELFORMAT_RGB555,
+    'BGR555': SDL_PIXELFORMAT_BGR555,
+    'ARGB4444': SDL_PIXELFORMAT_ARGB4444,
+    'RGBA4444': SDL_PIXELFORMAT_RGBA4444,
+    'ABGR4444': SDL_PIXELFORMAT_ABGR4444,
+    'BGRA4444': SDL_PIXELFORMAT_BGRA4444,
+    'ARGB1555': SDL_PIXELFORMAT_ARGB1555,
+    'RGBA5551': SDL_PIXELFORMAT_RGBA5551,
+    'ABGR1555': SDL_PIXELFORMAT_ABGR1555,
+    'BGRA5551': SDL_PIXELFORMAT_BGRA5551,
+    'RGB565': SDL_PIXELFORMAT_RGB565,
+    'BGR565': SDL_PIXELFORMAT_BGR565,
+    'RGB24': SDL_PIXELFORMAT_RGB24,
+    'BGR24': SDL_PIXELFORMAT_BGR24,
+    'RGB888': SDL_PIXELFORMAT_RGB888,
+    'RGBX8888': SDL_PIXELFORMAT_RGBX8888,
+    'BGR888': SDL_PIXELFORMAT_BGR888,
+    'BGRX8888': SDL_PIXELFORMAT_BGRX8888,
+    'ARGB8888': SDL_PIXELFORMAT_ARGB8888,
+    'RGBA8888': SDL_PIXELFORMAT_RGBA8888,
+    'ABGR8888': SDL_PIXELFORMAT_ABGR8888,
+    'BGRA8888': SDL_PIXELFORMAT_BGRA8888,
+    'ARGB2101010': SDL_PIXELFORMAT_ARGB2101010,
+    'RGBA32': SDL_PIXELFORMAT_RGBA32,
+    'ARGB32': SDL_PIXELFORMAT_ARGB32,
+    'BGRA32': SDL_PIXELFORMAT_BGRA32,
+    'ABGR32': SDL_PIXELFORMAT_ABGR32,
+    'YV12': SDL_PIXELFORMAT_YV12,
+    'IYUV': SDL_PIXELFORMAT_IYUV,
+    'YUY2': SDL_PIXELFORMAT_YUY2,
+    'UYVY': SDL_PIXELFORMAT_UYVY,
+    'YVYU': SDL_PIXELFORMAT_YVYU,
+    'NV12': SDL_PIXELFORMAT_NV12,
+    'NV21': SDL_PIXELFORMAT_NV21,
+    'EXTERNAL_OES': SDL_PIXELFORMAT_EXTERNAL_OES,
+}
 if sdl_version >= 2012:
-    ALL_PIXELFORMATS.append(SDL_PIXELFORMAT_BGR444)
-ALL_PIXELFORMATS = tuple(ALL_PIXELFORMATS)
+    NAME_MAP['BGR444'] = SDL_PIXELFORMAT_BGR444
+ALL_PIXELFORMATS = tuple(NAME_MAP.values())
 
 class SDL_Color(Structure):
     _fields_ = [("r", Uint8),
