@@ -1,5 +1,5 @@
-from ctypes import Structure, POINTER, c_int, c_void_p, c_char_p, c_float, \
-    py_object, CFUNCTYPE
+from ctypes import c_int, c_void_p, c_char_p, c_float, c_size_t, \
+    py_object, Structure, POINTER, CFUNCTYPE
 from .dll import _bind
 from .stdinc import Uint16, Uint32, SDL_bool
 from .rect import SDL_Point, SDL_Rect
@@ -14,13 +14,16 @@ __all__ = [
     "SDL_WINDOW_FULLSCREEN", "SDL_WINDOW_OPENGL", "SDL_WINDOW_SHOWN",
     "SDL_WINDOW_HIDDEN", "SDL_WINDOW_BORDERLESS",
     "SDL_WINDOW_RESIZABLE", "SDL_WINDOW_MINIMIZED",
-    "SDL_WINDOW_MAXIMIZED", "SDL_WINDOW_INPUT_GRABBED",
+    "SDL_WINDOW_MAXIMIZED",
+    "SDL_WINDOW_INPUT_GRABBED", "SDL_WINDOW_MOUSE_GRABBED",
     "SDL_WINDOW_INPUT_FOCUS", "SDL_WINDOW_MOUSE_FOCUS",
     "SDL_WINDOW_FULLSCREEN_DESKTOP", "SDL_WINDOW_FOREIGN",
     "SDL_WINDOW_ALLOW_HIGHDPI", "SDL_WINDOW_MOUSE_CAPTURE",
     "SDL_WINDOW_ALWAYS_ON_TOP", "SDL_WINDOW_SKIP_TASKBAR",
-    "SDL_WINDOW_UTILITY", "SDL_WINDOW_TOOLTIP", "SDL_WINDOW_POPUP_MENU",
+    "SDL_WINDOW_UTILITY", "SDL_WINDOW_TOOLTIP",
+    "SDL_WINDOW_POPUP_MENU", "SDL_WINDOW_KEYBOARD_GRABBED",
     "SDL_WINDOW_VULKAN", "SDL_WINDOW_METAL",
+    "SDL_WINDOW_INPUT_FOCUS",
 
     "SDL_WindowEventID",
     "SDL_WINDOWEVENT_NONE",
@@ -32,6 +35,7 @@ __all__ = [
     "SDL_WINDOWEVENT_LEAVE", "SDL_WINDOWEVENT_FOCUS_GAINED",
     "SDL_WINDOWEVENT_FOCUS_LOST", "SDL_WINDOWEVENT_CLOSE",
     "SDL_WINDOWEVENT_TAKE_FOCUS", "SDL_WINDOWEVENT_HIT_TEST",
+    "SDL_WINDOWEVENT_ICCPROF_CHANGED", "SDL_WINDOWEVENT_DISPLAY_CHANGED",
 
     "SDL_DisplayEventID",
     "SDL_DISPLAYEVENT_NONE", "SDL_DISPLAYEVENT_ORIENTATION",
@@ -42,6 +46,9 @@ __all__ = [
     "SDL_ORIENTATION_LANDSCAPE_FLIPPED", "SDL_ORIENTATION_PORTRAIT",
     "SDL_ORIENTATION_PORTRAIT_FLIPPED",
 
+    "SDL_FlashOperation",
+    "SDL_FLASH_CANCEL", "SDL_FLASH_BRIEFLY", "SDL_FLASH_UNTIL_FOCUSED",
+
     "SDL_GLattr",
     "SDL_GL_RED_SIZE",
     "SDL_GL_GREEN_SIZE", "SDL_GL_BLUE_SIZE", "SDL_GL_ALPHA_SIZE",
@@ -99,6 +106,7 @@ __all__ = [
     "SDL_GetDesktopDisplayMode", "SDL_GetCurrentDisplayMode",
     "SDL_GetClosestDisplayMode", "SDL_GetWindowDisplayIndex",
     "SDL_SetWindowDisplayMode", "SDL_GetWindowDisplayMode",
+    "SDL_GetWindowICCProfile",
     "SDL_GetWindowPixelFormat", "SDL_CreateWindow",
     "SDL_CreateWindowFrom", "SDL_GetWindowID", "SDL_GetWindowFromID",
     "SDL_GetWindowFlags", "SDL_SetWindowTitle", "SDL_GetWindowTitle",
@@ -112,10 +120,13 @@ __all__ = [
     "SDL_RestoreWindow", "SDL_SetWindowFullscreen",
     "SDL_GetWindowSurface", "SDL_UpdateWindowSurface",
     "SDL_UpdateWindowSurfaceRects", "SDL_SetWindowGrab",
-    "SDL_GetWindowGrab", "SDL_GetGrabbedWindow",
-    "SDL_SetWindowBrightness",
-    "SDL_GetWindowBrightness", "SDL_SetWindowGammaRamp",
-    "SDL_GetWindowGammaRamp", "SDL_DestroyWindow",
+    "SDL_SetWindowKeyboardGrab", "SDL_SetWindowMouseGrab",
+    "SDL_GetWindowGrab", "SDL_GetWindowKeyboardGrab",
+    "SDL_GetWindowMouseGrab", "SDL_GetGrabbedWindow",
+    "SDL_SetWindowMouseRect", "SDL_GetWindowMouseRect",
+    "SDL_SetWindowBrightness", "SDL_GetWindowBrightness",
+    "SDL_SetWindowGammaRamp", "SDL_GetWindowGammaRamp", 
+    "SDL_FlashWindow", "SDL_DestroyWindow",
     "SDL_DisableScreenSaver", "SDL_IsScreenSaverEnabled",
     "SDL_EnableScreenSaver",
     "SDL_SetWindowHitTest", "SDL_GL_LoadLibrary",
@@ -131,6 +142,7 @@ __all__ = [
     "SDL_GetWindowBordersSize", "SDL_GetWindowOpacity",
     "SDL_SetWindowOpacity", "SDL_SetWindowInputFocus",
     "SDL_SetWindowModalFor", "SDL_SetWindowResizable",
+    "SDL_SetWindowAlwaysOnTop",
 
     # Callback Functions
     "SDL_HitTest"
@@ -179,7 +191,8 @@ SDL_WINDOW_BORDERLESS = 0x00000010
 SDL_WINDOW_RESIZABLE = 0x00000020
 SDL_WINDOW_MINIMIZED = 0x00000040
 SDL_WINDOW_MAXIMIZED = 0x00000080
-SDL_WINDOW_INPUT_GRABBED = 0x00000100
+SDL_WINDOW_MOUSE_GRABBED = 0x00000100
+SDL_WINDOW_INPUT_GRABBED = SDL_WINDOW_MOUSE_GRABBED  # for < 2.0.16
 SDL_WINDOW_INPUT_FOCUS = 0x00000200
 SDL_WINDOW_MOUSE_FOCUS = 0x00000400
 SDL_WINDOW_FULLSCREEN_DESKTOP = (SDL_WINDOW_FULLSCREEN | 0x00001000)
@@ -187,11 +200,11 @@ SDL_WINDOW_FOREIGN = 0x00000800
 SDL_WINDOW_ALLOW_HIGHDPI = 0x00002000
 SDL_WINDOW_MOUSE_CAPTURE = 0x00004000
 SDL_WINDOW_ALWAYS_ON_TOP = 0x00008000
-
 SDL_WINDOW_SKIP_TASKBAR  = 0x00010000
 SDL_WINDOW_UTILITY = 0x00020000
 SDL_WINDOW_TOOLTIP = 0x00040000
 SDL_WINDOW_POPUP_MENU = 0x00080000
+SDL_WINDOW_KEYBOARD_GRABBED = 0x00100000
 SDL_WINDOW_VULKAN = 0x10000000
 SDL_WINDOW_METAL = 0x20000000
 
@@ -225,6 +238,8 @@ SDL_WINDOWEVENT_FOCUS_LOST = 13
 SDL_WINDOWEVENT_CLOSE = 14
 SDL_WINDOWEVENT_TAKE_FOCUS = 15
 SDL_WINDOWEVENT_HIT_TEST = 16
+SDL_WINDOWEVENT_ICCPROF_CHANGED = 17
+SDL_WINDOWEVENT_DISPLAY_CHANGED = 18
 
 
 SDL_DisplayEventID = c_int
@@ -244,6 +259,13 @@ SDL_ORIENTATION_PORTRAIT = 3
 SDL_ORIENTATION_PORTRAIT_FLIPPED = 4
 
 
+SDL_FlashOperation = c_int
+
+SDL_FLASH_CANCEL = 0
+SDL_FLASH_BRIEFLY = 1
+SDL_FLASH_UNTIL_FOCUSED = 2
+
+
 SDL_GLContext = c_void_p
 
 
@@ -338,6 +360,7 @@ SDL_GetClosestDisplayMode = _bind("SDL_GetClosestDisplayMode", [c_int, POINTER(S
 SDL_GetWindowDisplayIndex = _bind("SDL_GetWindowDisplayIndex", [POINTER(SDL_Window)], c_int)
 SDL_SetWindowDisplayMode = _bind("SDL_SetWindowDisplayMode", [POINTER(SDL_Window), POINTER(SDL_DisplayMode)], c_int)
 SDL_GetWindowDisplayMode = _bind("SDL_GetWindowDisplayMode", [POINTER(SDL_Window), POINTER(SDL_DisplayMode)], c_int)
+SDL_GetWindowICCProfile = _bind("SDL_GetWindowICCProfile", [POINTER(SDL_Window), POINTER(c_size_t)], c_void_p, added='2.0.18')
 SDL_GetWindowPixelFormat = _bind("SDL_GetWindowPixelFormat", [POINTER(SDL_Window)], Uint32)
 SDL_CreateWindow = _bind("SDL_CreateWindow", [c_char_p, c_int, c_int, c_int, c_int, Uint32], POINTER(SDL_Window))
 SDL_CreateWindowFrom = _bind("SDL_CreateWindowFrom", [c_void_p], POINTER(SDL_Window))
@@ -369,25 +392,33 @@ SDL_GetWindowSurface = _bind("SDL_GetWindowSurface", [POINTER(SDL_Window)], POIN
 SDL_UpdateWindowSurface = _bind("SDL_UpdateWindowSurface", [POINTER(SDL_Window)], c_int)
 SDL_UpdateWindowSurfaceRects = _bind("SDL_UpdateWindowSurfaceRects", [POINTER(SDL_Window), POINTER(SDL_Rect), c_int], c_int)
 SDL_SetWindowGrab = _bind("SDL_SetWindowGrab", [POINTER(SDL_Window), SDL_bool])
+SDL_SetWindowKeyboardGrab = _bind("SDL_SetWindowKeyboardGrab", [POINTER(SDL_Window), SDL_bool], added='2.0.16')
+SDL_SetWindowMouseGrab = _bind("SDL_SetWindowMouseGrab", [POINTER(SDL_Window), SDL_bool], added='2.0.16')
 SDL_GetWindowGrab = _bind("SDL_GetWindowGrab", [POINTER(SDL_Window)], SDL_bool)
-SDL_GetGrabbedWindow = _bind("SDL_GetGrabbedWindow", None, POINTER(SDL_Window))
+SDL_GetWindowKeyboardGrab = _bind("SDL_GetWindowKeyboardGrab", [POINTER(SDL_Window)], SDL_bool, added='2.0.16')
+SDL_GetWindowMouseGrab = _bind("SDL_GetWindowMouseGrab", [POINTER(SDL_Window)], SDL_bool, added='2.0.16')
+SDL_GetGrabbedWindow = _bind("SDL_GetGrabbedWindow", None, POINTER(SDL_Window), added='2.0.4')
+SDL_SetWindowMouseRect = _bind("SDL_SetWindowMouseRect", [POINTER(SDL_Window), POINTER(SDL_Rect)], c_int, added='2.0.18')
+SDL_GetWindowMouseRect = _bind("SDL_GetWindowMouseRect", [POINTER(SDL_Window)], POINTER(SDL_Rect), added='2.0.18')
 SDL_SetWindowBrightness = _bind("SDL_SetWindowBrightness", [POINTER(SDL_Window), c_float], c_int)
 SDL_GetWindowBrightness = _bind("SDL_GetWindowBrightness", [POINTER(SDL_Window)], c_float)
 SDL_SetWindowGammaRamp = _bind("SDL_SetWindowGammaRamp", [POINTER(SDL_Window), POINTER(Uint16), POINTER(Uint16), POINTER(Uint16)], c_int)
 SDL_GetWindowGammaRamp = _bind("SDL_GetWindowGammaRamp", [POINTER(SDL_Window), POINTER(Uint16), POINTER(Uint16), POINTER(Uint16)], c_int)
+SDL_FlashWindow = _bind("SDL_FlashWindow", [POINTER(SDL_Window), SDL_FlashOperation], c_int, added='2.0.16')
 SDL_DestroyWindow = _bind("SDL_DestroyWindow", [POINTER(SDL_Window)])
 SDL_IsScreenSaverEnabled = _bind("SDL_IsScreenSaverEnabled", None, SDL_bool)
 SDL_EnableScreenSaver = _bind("SDL_EnableScreenSaver")
 SDL_DisableScreenSaver = _bind("SDL_DisableScreenSaver")
-SDL_SetWindowHitTest = _bind("SDL_SetWindowHitTest", [POINTER(SDL_Window), SDL_HitTest, c_void_p], c_int)
-SDL_GetDisplayDPI = _bind("SDL_GetDisplayDPI", [c_int, POINTER(c_float), POINTER(c_float), POINTER(c_float)], c_int)
-SDL_GetDisplayUsableBounds = _bind("SDL_GetDisplayUsableBounds", [c_int, POINTER(SDL_Rect)], c_int)
-SDL_GetWindowBordersSize = _bind("SDL_GetWindowBordersSize", [POINTER(SDL_Window), POINTER(c_int), POINTER(c_int), POINTER(c_int), POINTER(c_int)], c_int)
-SDL_GetWindowOpacity = _bind("SDL_GetWindowOpacity", [POINTER(SDL_Window), POINTER(c_float)], c_int)
-SDL_SetWindowOpacity = _bind("SDL_SetWindowOpacity", [POINTER(SDL_Window), c_float], c_int)
-SDL_SetWindowInputFocus = _bind("SDL_SetWindowInputFocus", [POINTER(SDL_Window)], c_int)
-SDL_SetWindowModalFor = _bind("SDL_SetWindowModalFor", [POINTER(SDL_Window), POINTER(SDL_Window)], c_int)
-SDL_SetWindowResizable = _bind("SDL_SetWindowResizable", [POINTER(SDL_Window), SDL_bool])
+SDL_SetWindowHitTest = _bind("SDL_SetWindowHitTest", [POINTER(SDL_Window), SDL_HitTest, c_void_p], c_int, added='2.0.4')
+SDL_GetDisplayDPI = _bind("SDL_GetDisplayDPI", [c_int, POINTER(c_float), POINTER(c_float), POINTER(c_float)], c_int, added='2.0.4')
+SDL_GetDisplayUsableBounds = _bind("SDL_GetDisplayUsableBounds", [c_int, POINTER(SDL_Rect)], c_int, added='2.0.5')
+SDL_GetWindowBordersSize = _bind("SDL_GetWindowBordersSize", [POINTER(SDL_Window), POINTER(c_int), POINTER(c_int), POINTER(c_int), POINTER(c_int)], c_int, added='2.0.5')
+SDL_GetWindowOpacity = _bind("SDL_GetWindowOpacity", [POINTER(SDL_Window), POINTER(c_float)], c_int, added='2.0.5')
+SDL_SetWindowOpacity = _bind("SDL_SetWindowOpacity", [POINTER(SDL_Window), c_float], c_int, added='2.0.5')
+SDL_SetWindowInputFocus = _bind("SDL_SetWindowInputFocus", [POINTER(SDL_Window)], c_int, added='2.0.5')
+SDL_SetWindowModalFor = _bind("SDL_SetWindowModalFor", [POINTER(SDL_Window), POINTER(SDL_Window)], c_int, added='2.0.5')
+SDL_SetWindowResizable = _bind("SDL_SetWindowResizable", [POINTER(SDL_Window), SDL_bool], added='2.0.5')
+SDL_SetWindowAlwaysOnTop = _bind("SDL_SetWindowAlwaysOnTop", [POINTER(SDL_Window), SDL_bool], added='2.0.16')
 
 SDL_GL_LoadLibrary = _bind("SDL_GL_LoadLibrary", [c_char_p], c_int)
 SDL_GL_GetProcAddress = _bind("SDL_GL_GetProcAddress", [c_char_p], c_void_p)
